/*
   File       : oqs_ins_table.sql
	 Author     : Verweyen Consulting
	              Georg Verweyen
	 History    : 20070406 Creation
	 Parameters : &1 owner of the table
	              &2 name of the table
								&3 group of the KPI selection (e.g. period)
								   * must be an attribut name of the table
									 * can be empty, NULL
	 Tables     : oqs_meta_data     Insert
	              oqs_kpi_type      Select
								all_tab_columns   Select
								<&1.&2>           Select
	 Description: transfers the oracle metadata of a table 
	              combinate with the QS rules for the 
								column type into the table oqs_meta_data
*/
insert into oqs_meta_data  
select owner        as owner, 
       table_name   as table_name, 
			 column_name  as column_name,
       data_length  as column_len, 
			 substr(c.data_type,1,1)
			              as column_type,
			 owner||'.'||column_name||'.'||kpi_type 
			              as kpi_name,
			 kpi_type     as kpi_type,
			 '&3'         as kpi_group,
			 ''           as kpiwh_name,
			 ''           as kpiwh_type,
			 ''           as kpiwh_value
  from all_tab_columns c,
	     oqs_kpi_type    k
 where c.owner      = upper('&1.')
   and c.table_name = upper('&2.')
	 and c.data_type in ('VARCHAR2', 'NUMBER')
	 and substr(c.data_type,1,1) = k.column_type
	 and k.active = 'Y'
;
commit;
